@@ -608,7 +608,7 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
         wave_ref *= 10;
 
     cpl_frameset * grism_frame = fors_frameset_extract(frameset, "GRISM_TABLE");
-    std::auto_ptr<mosca::grism_config> grism_cfg = 
+    std::unique_ptr<mosca::grism_config> grism_cfg =
             fors_grism_config_from_frame(cpl_frameset_get_position(grism_frame, 0), wave_ref);
 
     
